@@ -1,6 +1,6 @@
 package Koha::Contrib::ARK;
 # ABSTRACT: ARK Management
-$Koha::Contrib::ARK::VERSION = '1.0.5';
+$Koha::Contrib::ARK::VERSION = '1.1.0';
 use Moose;
 use Modern::Perl;
 use JSON;
@@ -11,6 +11,7 @@ use Koha::Contrib::ARK::Writer;
 use Koha::Contrib::ARK::Update;
 use Koha::Contrib::ARK::Clear;
 use Koha::Contrib::ARK::Check;
+use Koha::Contrib::ARK::Fix;
 use Term::ProgressBar;
 use C4::Context;
 
@@ -19,10 +20,12 @@ use C4::Context;
 my $raw_actions = <<EOS;
 found_right_field      ARK found in the right field
 found_wrong_field      ARK found in the wrong field
+found_bad_ark          Bad ARK found in ARK field
 not_found              ARK not found
 build                  ARK Build
 clear                  Clear ARK field
 add                    Add ARK field
+fix                    Fix bad ARK found in correct ARK field
 remove_existing        Remove existing field while adding ARK field
 generated              ARK generated
 use_biblionumber       No koha.id field, use biblionumber to generate ARK
@@ -50,13 +53,15 @@ has cmd => (
     trigger => sub {
         my ($self, $cmd) = @_;
         $self->error("Invalid command: $cmd\n")
-            if $cmd !~ /check|clear|update/;
+            if $cmd !~ /check|clear|update|fix/;
         return $cmd;
     },
     default => 'check',
 );
 
 
+has fromwhere => ( is => 'rw', isa => 'Str' );
+
 has doit => ( is => 'rw', isa => 'Bool', default => 0 );
 
 
@@ -86,12 +91,21 @@ has current => (
 
 
 sub set_current {
-    my ($self, $biblionumber, $record) = @_;
-    my $current = { biblionumber => $biblionumber };
+    my ($self, $biblio, $record) = @_;
+    my $current = {
+        biblionumber => $biblio ? $biblio->biblionumber : 0,
+        modified => 0,
+    };
     $current->{ record } = tojson($record) if $record && $self->debug;
     $self->current($current);
 }
-    
+
+
+sub current_modified {
+    my $self = shift;
+    $self->current->{modified} = 1;
+}
+
 
 sub error {
     my ($self, $id, $more) = @_;
@@ -182,9 +196,10 @@ sub BUILD {
 
     # Instanciation reader/writer/converter
     $self->reader( Koha::Contrib::ARK::Reader->new(
-        ark => $self,
-        select => $self->cmd eq 'update' ? 'WithoutArk' :
-                  $self->cmd eq 'clear'  ? 'WithArk' : 'All',
+        ark         => $self,
+        fromwhere  => $self->fromwhere,
+        select     => $self->cmd eq 'update' ? 'WithoutArk' :
+                      $self->cmd eq 'clear'  ? 'WithArk' : 'All',
     ) );
     $explain->{result} = {
         count => $self->reader->total,
@@ -194,6 +209,7 @@ sub BUILD {
     $self->writer( Koha::Contrib::ARK::Writer->new( ark => $self ) );
     $self->action(
         $self->cmd eq 'check'  ? Koha::Contrib::ARK::Check->new( ark => $self ) :
+        $self->cmd eq 'fix'    ? Koha::Contrib::ARK::Fix->new( ark => $self ) :
         $self->cmd eq 'update' ? Koha::Contrib::ARK::Update->new( ark => $self ) :
                                  Koha::Contrib::ARK::Clear->new( ark => $self )
     );
@@ -215,6 +231,7 @@ sub build_ark {
         $id = $kfield->{letter}
             ? $id->subfield($kfield->{letter})
             : $id->value;
+        $id =~ s/^ *//; $id =~ s/ *$//; # trim left/right
     }
     unless ($id) {
         $self->what_append('use_biblionumber');
@@ -256,11 +273,11 @@ sub run {
         $progress = Term::ProgressBar->new({ count => $self->reader->total })
             if $self->verbose;
         my $next_update = 0;
-        while ( my ($biblionumber, $record) = $self->reader->read() ) {
+        while ( my ($biblio, $record) = $self->reader->read() ) {
             if ( $record ) {
-                $self->action->action($biblionumber, $record);
-                if ( $self->cmd ne 'check' ) {
-                    $self->writer->write($biblionumber, $record);
+                $self->action->action($biblio->biblionumber, $record);
+                if ( $self->cmd ne 'check' && $self->current->{modified} ) {
+                    $self->writer->write($biblio, $record);
                 }
                 push @{$self->explain->{result}->{records}}, $self->current;
             }
@@ -288,7 +305,7 @@ Koha::Contrib::ARK - ARK Management
 
 =head1 VERSION
 
-version 1.0.5
+version 1.1.0
 
 =head1 ATTRIBUTES
 
@@ -297,6 +314,10 @@ version 1.0.5
 What processing? One of those values: check, clear, update. By default,
 'check'.
 
+=head2 fromwhere
+
+WHERE clause to select biblio records in biblio_metadata table
+
 =head2 doit
 
 Is the process effective?
@@ -319,7 +340,7 @@ What happens on the current biblio record?
 
 =head1 METHODS
 
-=head2 set_current($biblionumber, $record)
+=head2 set_current($biblio, $record)
 
 Set the current biblio record. Called by the biblio records reader.
 
@@ -338,7 +359,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Fréderic Demians.
+This software is Copyright (c) 2024 by Fréderic Demians.
 
 This is free software, licensed under:
 
