@@ -1,6 +1,6 @@
 package Koha::Contrib::ARK::Check;
 # ABSTRACT: Check Koha ARK field
-$Koha::Contrib::ARK::Check::VERSION = '1.0.5';
+$Koha::Contrib::ARK::Check::VERSION = '1.1.0';
 use Moose;
 use Modern::Perl;
 
@@ -19,6 +19,15 @@ sub action {
     my $ark_value = $self->ark->build_ark($biblionumber, $record);
     # Searching ARK everywhere
     my $found = 0;
+
+    # Is a bad ARK found in the correct field?
+    if (my $field = $record->field($tag)) {
+        my $value = $letter ? $field->subfield($letter) : $field->value;
+        $self->ark->what_append('found_bad_ark', "Found \"$value\" in place of \"$ark_value\"")
+            if $value ne $ark_value;
+    }
+
+    # Is the correct ARK somewhere, good/wrong field?
     for my $field ( @{$record->fields} ) {
         if ( ref $field eq 'MARC::Moose::Field::Std' ) {
             for ( @{$field->subf} ) {
@@ -68,7 +77,7 @@ Koha::Contrib::ARK::Check - Check Koha ARK field
 
 =head1 VERSION
 
-version 1.0.5
+version 1.1.0
 
 =head1 AUTHOR
 
@@ -76,7 +85,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Fréderic Demians.
+This software is Copyright (c) 2024 by Fréderic Demians.
 
 This is free software, licensed under:
 
