@@ -1,9 +1,9 @@
 package Koha::Contrib::ARK::Writer;
 # ABSTRACT: Write biblio records into Koha Catalog
-$Koha::Contrib::ARK::Writer::VERSION = '1.0.5';
+$Koha::Contrib::ARK::Writer::VERSION = '1.1.0';
 use Moose;
 use Modern::Perl;
-use C4::Biblio;
+use C4::Biblio qw/ ModBiblio /;
 
 with 'MooseX::RW::Writer';
 
@@ -12,14 +12,13 @@ has ark => ( is => 'rw', isa => 'Koha::Contrib::ARK' );
 
 
 sub write {
-    my ($self, $biblionumber, $record) = @_;
+    my ($self, $biblio, $record) = @_;
 
     return unless $record;
 
     my $a = $self->ark;
     if ($a->doit) {
-        my $fc = GetFrameworkCode($biblionumber);
-        ModBiblio( $record->as('Legacy'), $biblionumber, $fc );
+        ModBiblio( $record->as('Legacy'), $biblio->biblionumber, $biblio->frameworkcode);
     }
     $a->current->{after} = Koha::Contrib::ARK::tojson($record)
         if $a->debug;
@@ -40,7 +39,7 @@ Koha::Contrib::ARK::Writer - Write biblio records into Koha Catalog
 
 =head1 VERSION
 
-version 1.0.5
+version 1.1.0
 
 =head1 ATTRIBUTES
 
@@ -54,7 +53,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Fréderic Demians.
+This software is Copyright (c) 2024 by Fréderic Demians.
 
 This is free software, licensed under:
 
